use std::path::Path;

use lazy_static::lazy_static;

pub mod cli;
pub mod config;
use config::Config;

mod analyzer;

/// 定义 crate::Error
/// 大部分函数返回的错误
pub type Error = Box<dyn std::error::Error + Send + Sync>;

/// 定义 crate::Result
pub type Result<T> = std::result::Result<T, Error>;

// 首先需要读取并载入配置信息
// 默认为 /etc/cuavrs 下
lazy_static! {
    pub static ref CONFIG: Config = {
        let default = Path::new("/etc/cuavrs/cuvat.json");
        if default.is_file() {
            Config::from(default.to_str().unwrap()).unwrap()
        } else {
            Config::from("cuvat.json").unwrap()
        }
    };
}

pub fn cumain() -> Result<()> {
    ccutils::set_up_logging()?;
    let cli = cli::parse();
    // 初始化使用 rpm 默认配置
    rpm_rs::configure();

    analyzer::cuvat_run(&cli)
}
